Note

Struct Note 

pub struct Note {
    pub value: Option<String>,
    pub mime: Option<String>,
    pub translation: Option<Translation>,
    pub citation: Option<Source>,
    pub language: Option<String>,
}
A NOTE_STRUCTURE containing additional information for understanding the enclosing data.

Notes provide supplementary information submitted by the data contributor to help clarify or explain the genealogical data they’re attached to. They serve as contextual annotations that enhance the understanding of the associated records.

Header Notes

When used as a substructure of HEAD, the note should describe the document’s genealogical scope in terms of “ancestors or descendants of” a specific person. This helps recipients understand what genealogical information the document contains.

GEDCOM Specification

Conforms to the GEDCOM NOTE_STRUCTURE specification. See: https://gedcom.io/specifications/FamilySearchGEDCOMv7.html#NOTE See: https://gedcom.io/specifications/FamilySearchGEDCOMv7.html#NOTE_STRUCTURE

Fields

value: Option<String>mime: Option<String>

tag: MIME, indicates the media type of the payload of the superstructure, as defined by BCP 13. As of version 7.0, only 2 media types are supported by this structure: text/plain and text/html

translation: Option<Translation>

tag: TRAN, a type of TRAN for unstructured human-readable text, such as is found in NOTE and SNOTE payloads.

citation: Option<Source>

tag: SOUR, a citation indicating that the pointed-to source record supports the claims made in the superstructure. See https://gedcom.io/specifications/FamilySearchGEDCOMv7.html#SOURCE_CITATION.

language: Option<String>

tag: LANG, The primary human language of the superstructure. The primary language in which the Text-typed payloads of the superstructure and its substructures appear. See https://gedcom.io/specifications/FamilySearchGEDCOMv7.html#LANG.

Implementations

Source

impl Note

pub fn new( tokenizer: &mut Tokenizer<'_>, level: u8, ) -> Result<Note, GedcomError>

Creates a new Note from a Tokenizer.

Errors

This function will return an error if parsing fails.